@@ -4,26 +4,26 @@ import (
 	"errors"
 	"sort"
 
-	"github.com/elves/elvish/pkg/eval"
-	"github.com/elves/elvish/pkg/eval/vals"
-	"github.com/elves/elvish/pkg/parse"
-	"github.com/elves/elvish/pkg/ui"
-	"github.com/xiaq/persistent/hashmap"
+	"src.elv.sh/pkg/eval"
+	"src.elv.sh/pkg/eval/vals"
+	"src.elv.sh/pkg/parse"
+	"src.elv.sh/pkg/persistent/hashmap"
+	"src.elv.sh/pkg/ui"
 )
 
 var errValueShouldBeFn = errors.New("value should be function")
 
-// BindingMap is a special Map that converts its key to ui.Key and ensures
-// that its values satisfy eval.CallableValue.
-type BindingMap struct {
+// A special Map that converts its key to ui.Key and ensures that its values
+// satisfy eval.CallableValue.
+type bindingsMap struct {
 	hashmap.Map
 }
 
-var EmptyBindingMap = BindingMap{vals.EmptyMap}
+var emptyBindingsMap = bindingsMap{vals.EmptyMap}
 
 // Repr returns the representation of the binding table as if it were an
 // ordinary map keyed by strings.
-func (bt BindingMap) Repr(indent int) string {
+func (bt bindingsMap) Repr(indent int) string {
 	var keys ui.Keys
 	for it := bt.Map.Iterator(); it.HasElem(); it.Next() {
 		k, _ := it.Elem()
@@ -42,7 +42,7 @@ func (bt BindingMap) Repr(indent int) string {
 }
 
 // Index converts the index to ui.Key and uses the Index of the inner Map.
-func (bt BindingMap) Index(index interface{}) (interface{}, error) {
+func (bt bindingsMap) Index(index interface{}) (interface{}, error) {
 	key, err := toKey(index)
 	if err != nil {
 		return nil, err
@@ -50,12 +50,12 @@ func (bt BindingMap) Index(index interface{}) (interface{}, error) {
 	return vals.Index(bt.Map, key)
 }
 
-func (bt BindingMap) HasKey(k interface{}) bool {
+func (bt bindingsMap) HasKey(k interface{}) bool {
 	_, ok := bt.Map.Index(k)
 	return ok
 }
 
-func (bt BindingMap) GetKey(k ui.Key) eval.Callable {
+func (bt bindingsMap) GetKey(k ui.Key) eval.Callable {
 	v, ok := bt.Map.Index(k)
 	if !ok {
 		panic("get called when key not present")
@@ -65,7 +65,7 @@ func (bt BindingMap) GetKey(k ui.Key) eval.Callable {
 
 // Assoc converts the index to ui.Key, ensures that the value is CallableValue,
 // uses the Assoc of the inner Map and converts the result to a BindingTable.
-func (bt BindingMap) Assoc(k, v interface{}) (interface{}, error) {
+func (bt bindingsMap) Assoc(k, v interface{}) (interface{}, error) {
 	key, err := toKey(k)
 	if err != nil {
 		return nil, err
@@ -75,34 +75,34 @@ func (bt BindingMap) Assoc(k, v interface{}) (interface{}, error) {
 		return nil, errValueShouldBeFn
 	}
 	map2 := bt.Map.Assoc(key, f)
-	return BindingMap{map2}, nil
+	return bindingsMap{map2}, nil
 }
 
 // Dissoc converts the key to ui.Key and calls the Dissoc method of the inner
 // map.
-func (bt BindingMap) Dissoc(k interface{}) interface{} {
+func (bt bindingsMap) Dissoc(k interface{}) interface{} {
 	key, err := toKey(k)
 	if err != nil {
 		// Key is invalid; dissoc is no-op.
 		return bt
 	}
-	return BindingMap{bt.Map.Dissoc(key)}
+	return bindingsMap{bt.Map.Dissoc(key)}
 }
 
-func MakeBindingMap(raw hashmap.Map) (BindingMap, error) {
+func makeBindingMap(raw hashmap.Map) (bindingsMap, error) {
 	converted := vals.EmptyMap
 	for it := raw.Iterator(); it.HasElem(); it.Next() {
 		k, v := it.Elem()
 		f, ok := v.(eval.Callable)
 		if !ok {
-			return EmptyBindingMap, errValueShouldBeFn
+			return emptyBindingsMap, errValueShouldBeFn
 		}
 		key, err := toKey(k)
 		if err != nil {
-			return BindingMap{}, err
+			return bindingsMap{}, err
 		}
 		converted = converted.Assoc(key, f)
 	}
 
-	return BindingMap{converted}, nil
+	return bindingsMap{converted}, nil
 }
