@@ -8,15 +8,16 @@ import (
 	"sync"
 	"unicode/utf8"
 
-	"github.com/elves/elvish/pkg/cli"
-	"github.com/elves/elvish/pkg/cli/addons/completion"
-	"github.com/elves/elvish/pkg/edit/complete"
-	"github.com/elves/elvish/pkg/eval"
-	"github.com/elves/elvish/pkg/eval/vals"
-	"github.com/elves/elvish/pkg/fsutil"
-	"github.com/elves/elvish/pkg/parse"
-	"github.com/elves/elvish/pkg/strutil"
-	"github.com/xiaq/persistent/hash"
+	"src.elv.sh/pkg/cli"
+	"src.elv.sh/pkg/cli/mode"
+	"src.elv.sh/pkg/cli/tk"
+	"src.elv.sh/pkg/edit/complete"
+	"src.elv.sh/pkg/eval"
+	"src.elv.sh/pkg/eval/vals"
+	"src.elv.sh/pkg/fsutil"
+	"src.elv.sh/pkg/parse"
+	"src.elv.sh/pkg/persistent/hash"
+	"src.elv.sh/pkg/strutil"
 )
 
 //elvdoc:var completion:arg-completer
@@ -158,7 +159,7 @@ func complexCandidate(fm *eval.Frame, opts complexCandidateOpts, stem string) co
 // Starts the completion mode. However, if all the candidates share a non-empty
 // prefix and that prefix starts with the seed, inserts the prefix instead.
 
-func completionStart(app cli.App, binding cli.Handler, cfg complete.Config, smart bool) {
+func completionStart(app cli.App, bindings tk.Bindings, cfg complete.Config, smart bool) {
 	buf := app.CodeArea().CopyState().Buffer
 	result, err := complete.Complete(
 		complete.CodeBuffer{Content: buf.Content, Dot: buf.Dot}, cfg)
@@ -180,10 +181,10 @@ func completionStart(app cli.App, binding cli.Handler, cfg complete.Config, smar
 		}
 		if prefix != "" {
 			insertedPrefix := false
-			app.CodeArea().MutateState(func(s *cli.CodeAreaState) {
+			app.CodeArea().MutateState(func(s *tk.CodeAreaState) {
 				rep := s.Buffer.Content[result.Replace.From:result.Replace.To]
 				if len(prefix) > len(rep) && strings.HasPrefix(prefix, rep) {
-					s.Pending = cli.PendingCode{
+					s.Pending = tk.PendingCode{
 						Content: prefix,
 						From:    result.Replace.From, To: result.Replace.To}
 					s.ApplyPending()
@@ -195,9 +196,16 @@ func completionStart(app cli.App, binding cli.Handler, cfg complete.Config, smar
 			}
 		}
 	}
-	completion.Start(app, completion.Config{
+	w, err := mode.NewCompletion(app, mode.CompletionSpec{
 		Name: result.Name, Replace: result.Replace, Items: result.Items,
-		Binding: binding})
+		Filter: filterSpec, Bindings: bindings,
+	})
+	if w != nil {
+		app.SetAddon(w, false)
+	}
+	if err != nil {
+		app.Notify(err.Error())
+	}
 }
 
 //elvdoc:fn completion:close
@@ -205,8 +213,8 @@ func completionStart(app cli.App, binding cli.Handler, cfg complete.Config, smar
 // Closes the completion mode UI.
 
 func initCompletion(ed *Editor, ev *eval.Evaler, nb eval.NsBuilder) {
-	bindingVar := newBindingVar(EmptyBindingMap)
-	binding := newMapBinding(ed, ev, bindingVar)
+	bindingVar := newBindingVar(emptyBindingsMap)
+	bindings := newMapBindings(ed, ev, bindingVar)
 	matcherMapVar := newMapVar(vals.EmptyMap)
 	argGeneratorMapVar := newMapVar(vals.EmptyMap)
 	cfg := func() complete.Config {
@@ -238,9 +246,8 @@ func initCompletion(ed *Editor, ev *eval.Evaler, nb eval.NsBuilder) {
 			"matcher":       matcherMapVar,
 		}.AddGoFns("<edit:completion>:", map[string]interface{}{
 			"accept":      func() { listingAccept(app) },
-			"smart-start": func() { completionStart(app, binding, cfg(), true) },
-			"start":       func() { completionStart(app, binding, cfg(), false) },
-			"close":       func() { completion.Close(app) },
+			"smart-start": func() { completionStart(app, bindings, cfg(), true) },
+			"start":       func() { completionStart(app, bindings, cfg(), false) },
 			"up":          func() { listingUp(app) },
 			"down":        func() { listingDown(app) },
 			"up-cycle":    func() { listingUpCycle(app) },
@@ -301,15 +308,20 @@ func wrapArgGenerator(gen complete.ArgGenerator) wrappedArgGenerator {
 		if err != nil {
 			return err
 		}
-		ch := fm.OutputChan()
+		out := fm.ValueOutput()
 		for _, rawItem := range rawItems {
+			var v interface{}
 			switch rawItem := rawItem.(type) {
 			case complete.ComplexItem:
-				ch <- complexItem(rawItem)
+				v = complexItem(rawItem)
 			case complete.PlainItem:
-				ch <- string(rawItem)
+				v = string(rawItem)
 			default:
-				ch <- rawItem
+				v = rawItem
+			}
+			err := out.Put(v)
+			if err != nil {
+				return err
 			}
 		}
 		return nil
@@ -349,23 +361,31 @@ type matcherOpts struct {
 
 func (*matcherOpts) SetDefaultOptions() {}
 
-type wrappedMatcher func(fm *eval.Frame, opts matcherOpts, seed string, inputs eval.Inputs)
+type wrappedMatcher func(fm *eval.Frame, opts matcherOpts, seed string, inputs eval.Inputs) error
 
 func wrapMatcher(m matcher) wrappedMatcher {
-	return func(fm *eval.Frame, opts matcherOpts, seed string, inputs eval.Inputs) {
-		out := fm.OutputChan()
+	return func(fm *eval.Frame, opts matcherOpts, seed string, inputs eval.Inputs) error {
+		out := fm.ValueOutput()
+		var errOut error
 		if opts.IgnoreCase || (opts.SmartCase && seed == strings.ToLower(seed)) {
 			if opts.IgnoreCase {
 				seed = strings.ToLower(seed)
 			}
 			inputs(func(v interface{}) {
-				out <- m(strings.ToLower(vals.ToString(v)), seed)
+				if errOut != nil {
+					return
+				}
+				errOut = out.Put(m(strings.ToLower(vals.ToString(v)), seed))
 			})
 		} else {
 			inputs(func(v interface{}) {
-				out <- m(vals.ToString(v), seed)
+				if errOut != nil {
+					return
+				}
+				errOut = out.Put(m(vals.ToString(v), seed))
 			})
 		}
+		return errOut
 	}
 }
 
