@@ -3,16 +3,16 @@ package edit
 import (
 	"testing"
 
-	"github.com/elves/elvish/pkg/cli/term"
-	"github.com/elves/elvish/pkg/eval"
-	. "github.com/elves/elvish/pkg/eval/evaltest"
-	"github.com/elves/elvish/pkg/eval/vals"
-	"github.com/elves/elvish/pkg/testutil"
+	"src.elv.sh/pkg/cli/term"
+	"src.elv.sh/pkg/eval"
+	. "src.elv.sh/pkg/eval/evaltest"
+	"src.elv.sh/pkg/eval/vals"
+	"src.elv.sh/pkg/testutil"
 )
 
 func TestCompletionAddon(t *testing.T) {
-	f := setup()
-	defer f.Cleanup()
+	f := setup(t)
+
 	testutil.ApplyDir(testutil.Dir{"a": "", "b": ""})
 
 	feedInput(f.TTYCtrl, "echo \t")
@@ -27,8 +27,8 @@ func TestCompletionAddon(t *testing.T) {
 }
 
 func TestCompletionAddon_CompletesLongestCommonPrefix(t *testing.T) {
-	f := setup()
-	defer f.Cleanup()
+	f := setup(t)
+
 	testutil.ApplyDir(testutil.Dir{"foo1": "", "foo2": "", "foo": "", "fox": ""})
 
 	feedInput(f.TTYCtrl, "echo \t")
@@ -49,8 +49,8 @@ func TestCompletionAddon_CompletesLongestCommonPrefix(t *testing.T) {
 }
 
 func TestCompleteFilename(t *testing.T) {
-	f := setup()
-	defer f.Cleanup()
+	f := setup(t)
+
 	testutil.ApplyDir(testutil.Dir{"d": testutil.Dir{"a": "", "b": ""}})
 
 	evals(f.Evaler, `@cands = (edit:complete-filename ls ./d/a)`)
@@ -59,6 +59,8 @@ func TestCompleteFilename(t *testing.T) {
 		vals.MakeList(
 			complexItem{Stem: "./d/a", CodeSuffix: " "},
 			complexItem{Stem: "./d/b", CodeSuffix: " "}))
+
+	testThatOutputErrorIsBubbled(t, f, "edit:complete-filename ls ''")
 }
 
 func TestComplexCandidate(t *testing.T) {
@@ -81,16 +83,14 @@ func TestComplexCandidate(t *testing.T) {
 func TestComplexCandidate_InEditModule(t *testing.T) {
 	// A sanity check that the complex-candidate command is part of the edit
 	// module.
-	f := setup()
-	defer f.Cleanup()
+	f := setup(t)
 
 	evals(f.Evaler, `stem = (edit:complex-candidate stem)[stem]`)
 	testGlobal(t, f.Evaler, "stem", "stem")
 }
 
 func TestCompletionArgCompleter_ArgsAndValueOutput(t *testing.T) {
-	f := setup()
-	defer f.Cleanup()
+	f := setup(t)
 
 	evals(f.Evaler,
 		`foo-args = []`,
@@ -115,8 +115,7 @@ func TestCompletionArgCompleter_ArgsAndValueOutput(t *testing.T) {
 }
 
 func TestCompletionArgCompleter_BytesOutput(t *testing.T) {
-	f := setup()
-	defer f.Cleanup()
+	f := setup(t)
 
 	evals(f.Evaler,
 		`fn foo { }`,
@@ -137,8 +136,7 @@ func TestCompletionArgCompleter_BytesOutput(t *testing.T) {
 }
 
 func TestCompleteSudo(t *testing.T) {
-	f := setup()
-	defer f.Cleanup()
+	f := setup(t)
 
 	evals(f.Evaler,
 		`fn foo { }`,
@@ -151,8 +149,8 @@ func TestCompleteSudo(t *testing.T) {
 }
 
 func TestCompletionMatcher(t *testing.T) {
-	f := setup()
-	defer f.Cleanup()
+	f := setup(t)
+
 	testutil.ApplyDir(testutil.Dir{"foo": "", "oof": ""})
 
 	evals(f.Evaler, `edit:completion:matcher[''] = $edit:match-substr~`)
@@ -168,8 +166,7 @@ func TestCompletionMatcher(t *testing.T) {
 }
 
 func TestBuiltinMatchers(t *testing.T) {
-	f := setup()
-	defer f.Cleanup()
+	f := setup(t)
 
 	evals(f.Evaler,
 		`@prefix = (edit:match-prefix ab [ab abc cab acb ba [ab] [a b] [b a]])`,
@@ -181,11 +178,12 @@ func TestBuiltinMatchers(t *testing.T) {
 		"substr": vals.MakeList(true, true, true, false, false, true, false, false),
 		"subseq": vals.MakeList(true, true, true, true, false, true, true, false),
 	})
+
+	testThatOutputErrorIsBubbled(t, f, "edit:match-prefix ab [ab]")
 }
 
 func TestBuiltinMatchers_Options(t *testing.T) {
-	f := setup()
-	defer f.Cleanup()
+	f := setup(t)
 
 	// The two options work identically on all the builtin matchers, so we only
 	// test for match-prefix for simplicity.
@@ -201,4 +199,6 @@ func TestBuiltinMatchers_Options(t *testing.T) {
 		"c": vals.MakeList(true, true, true),
 		"d": vals.MakeList(false, true, false),
 	})
+
+	testThatOutputErrorIsBubbled(t, f, "edit:match-prefix &ignore-case ab [ab]")
 }
