@@ -8,14 +8,18 @@ import (
 	"io/ioutil"
 	"math/rand"
 	"net"
-	"strconv"
 	"sync"
 	"time"
 	"unicode/utf8"
 
-	"github.com/elves/elvish/pkg/diag"
-	"github.com/elves/elvish/pkg/eval/vals"
-	"github.com/elves/elvish/pkg/parse"
+	"src.elv.sh/pkg/diag"
+	"src.elv.sh/pkg/eval/vals"
+	"src.elv.sh/pkg/parse"
+)
+
+var (
+	ErrNegativeSleepDuration = errors.New("sleep duration must be >= zero")
+	ErrInvalidSleepDuration  = errors.New("invalid sleep duration")
 )
 
 // Builtins that have not been put into their own groups go here.
@@ -30,14 +34,12 @@ func init() {
 
 		"eval":    eval,
 		"use-mod": useMod,
-		"-source": source,
 
 		"deprecate": deprecate,
 
 		// Time
-		"esleep": sleep,
-		"sleep":  sleep,
-		"time":   timeCmd,
+		"sleep": sleep,
+		"time":  timeCmd,
 
 		"-ifaddrs": _ifaddrs,
 	})
@@ -86,11 +88,15 @@ func nop(opts RawOptions, args ...interface{}) {
 //
 // The terminology and definition of "kind" is subject to change.
 
-func kindOf(fm *Frame, args ...interface{}) {
-	out := fm.OutputChan()
+func kindOf(fm *Frame, args ...interface{}) error {
+	out := fm.ValueOutput()
 	for _, a := range args {
-		out <- vals.Kind(a)
+		err := out.Put(vals.Kind(a))
+		if err != nil {
+			return err
+		}
 	}
+	return nil
 }
 
 //elvdoc:fn constantly
@@ -129,11 +135,15 @@ func constantly(args ...interface{}) Callable {
 	// TODO(xiaq): Repr of this function is not right.
 	return NewGoFn(
 		"created by constantly",
-		func(fm *Frame) {
-			out := fm.OutputChan()
+		func(fm *Frame) error {
+			out := fm.ValueOutput()
 			for _, v := range args {
-				out <- v
+				err := out.Put(v)
+				if err != nil {
+					return err
+				}
 			}
+			return nil
 		},
 	)
 }
@@ -289,27 +299,6 @@ func useMod(fm *Frame, spec string) (*Ns, error) {
 	return use(fm, spec, nil)
 }
 
-//elvdoc:fn -source
-//
-// ```elvish
-// -source $filename
-// ```
-//
-// Equivalent to `eval (slurp <$filename)`. Deprecated.
-
-func source(fm *Frame, fname string) error {
-	code, err := readFileUTF8(fname)
-	if err != nil {
-		return err
-	}
-	src := parse.Source{Name: fname, Code: code, IsFile: true}
-	// Amalgamate the up and local scope into a new scope to use as the global
-	// scope to evaluate the code in.
-	ns := CombineNs(fm.up, fm.local)
-	_, exc := fm.Eval(src, nil, ns)
-	return exc
-}
-
 func readFileUTF8(fname string) (string, error) {
 	bytes, err := ioutil.ReadFile(fname)
 	if err != nil {
@@ -416,27 +405,26 @@ var TimeAfter = func(fm *Frame, d time.Duration) <-chan time.Time {
 // ```
 
 func sleep(fm *Frame, duration interface{}) error {
+	var f float64
 	var d time.Duration
 
-	switch duration := duration.(type) {
-	case float64:
-		d = time.Duration(float64(time.Second) * duration)
-	case string:
-		f, err := strconv.ParseFloat(duration, 64)
-		if err == nil { // it's a simple number assumed to have units == seconds
-			d = time.Duration(float64(time.Second) * f)
-		} else {
+	if err := vals.ScanToGo(duration, &f); err == nil {
+		d = time.Duration(f * float64(time.Second))
+	} else {
+		// See if it is a duration string rather than a simple number.
+		switch duration := duration.(type) {
+		case string:
 			d, err = time.ParseDuration(duration)
 			if err != nil {
-				return errors.New("invalid sleep duration")
+				return ErrInvalidSleepDuration
 			}
+		default:
+			return ErrInvalidSleepDuration
 		}
-	default:
-		return errors.New("invalid sleep duration")
 	}
 
 	if d < 0 {
-		return fmt.Errorf("sleep duration must be >= zero")
+		return ErrNegativeSleepDuration
 	}
 
 	select {
@@ -496,7 +484,10 @@ func timeCmd(fm *Frame, opts timeOpt, f Callable) error {
 			err = errCb
 		}
 	} else {
-		fmt.Fprintln(fm.OutputFile(), dt)
+		_, errWrite := fmt.Fprintln(fm.ByteOutput(), dt)
+		if err == nil {
+			err = errWrite
+		}
 	}
 
 	return err
@@ -517,9 +508,12 @@ func _ifaddrs(fm *Frame) error {
 	if err != nil {
 		return err
 	}
-	out := fm.OutputChan()
+	out := fm.ValueOutput()
 	for _, addr := range addrs {
-		out <- addr.String()
+		err := out.Put(addr.String())
+		if err != nil {
+			return err
+		}
 	}
 	return nil
 }
