@@ -21,11 +21,12 @@ import (
 	"path/filepath"
 	"strings"
 
-	"github.com/elves/elvish/pkg/diag"
-	"github.com/elves/elvish/pkg/eval/mods/bundled"
-	"github.com/elves/elvish/pkg/eval/vals"
-	"github.com/elves/elvish/pkg/eval/vars"
-	"github.com/elves/elvish/pkg/parse"
+	"src.elv.sh/pkg/diag"
+	"src.elv.sh/pkg/eval/mods/bundled"
+	"src.elv.sh/pkg/eval/vals"
+	"src.elv.sh/pkg/eval/vars"
+	"src.elv.sh/pkg/parse"
+	"src.elv.sh/pkg/parse/cmpd"
 )
 
 type compileBuiltin func(*compiler, *parse.Form) effectOp
@@ -245,8 +246,8 @@ func (op *delElemOp) exec(fm *Frame) Exception {
 func compileFn(cp *compiler, fn *parse.Form) effectOp {
 	args := cp.walkArgs(fn)
 	nameNode := args.next()
-	name := mustString(cp, nameNode, "must be a literal string")
-	bodyNode := args.nextMustLambda()
+	name := stringLiteralOrError(cp, nameNode, "function name")
+	bodyNode := args.nextMustLambda("function body")
 	args.mustEnd()
 
 	// Define the variable before compiling the body, so that the body may refer
@@ -299,17 +300,14 @@ func compileUse(cp *compiler, fn *parse.Form) effectOp {
 		end := fn.Head.Range().To
 		cp.errorpf(diag.PointRanging(end), "lack module name")
 	case 1:
-		spec = mustString(cp, fn.Args[0],
-			"module spec should be a literal string")
+		spec = stringLiteralOrError(cp, fn.Args[0], "module spec")
 		// Use the last path component as the name; for instance, if path =
 		// "a/b/c/d", name is "d". If path doesn't have slashes, name = path.
 		name = spec[strings.LastIndexByte(spec, '/')+1:]
 	case 2:
 		// TODO(xiaq): Allow using variable as module path
-		spec = mustString(cp, fn.Args[0],
-			"module spec should be a literal string")
-		name = mustString(cp, fn.Args[1],
-			"module name should be a literal string")
+		spec = stringLiteralOrError(cp, fn.Args[0], "module spec")
+		name = stringLiteralOrError(cp, fn.Args[1], "module name")
 	default: // > 2
 		cp.errorpf(diag.MixedRanging(fn.Args[2], fn.Args[len(fn.Args)-1]),
 			"superfluous argument(s)")
@@ -347,7 +345,7 @@ func use(fm *Frame, spec string, r diag.Ranger) (*Ns, error) {
 				return nil, err
 			}
 		}
-		path := filepath.Clean(dir + "/" + spec + ".elv")
+		path := filepath.Clean(dir + "/" + spec)
 		return useFromFile(fm, spec, path, r)
 	}
 	if ns, ok := fm.Evaler.modules[spec]; ok {
@@ -357,11 +355,16 @@ func use(fm *Frame, spec string, r diag.Ranger) (*Ns, error) {
 		return evalModule(fm, spec,
 			parse.Source{Name: "[bundled " + spec + "]", Code: code}, r)
 	}
-	libDir := fm.Evaler.getLibDir()
-	if libDir == "" {
-		return nil, noSuchModule{spec}
+	// TODO: For non-relative imports, use the spec (instead of the full path)
+	// as the module key instead to avoid searching every time.
+	for _, dir := range fm.Evaler.getLibDirs() {
+		ns, err := useFromFile(fm, spec, filepath.Join(dir, spec), r)
+		if _, isNoSuchModule := err.(noSuchModule); isNoSuchModule {
+			continue
+		}
+		return ns, err
 	}
-	return useFromFile(fm, spec, libDir+"/"+spec+".elv", r)
+	return nil, noSuchModule{spec}
 }
 
 // TODO: Make access to fm.Evaler.modules concurrency-safe.
@@ -369,14 +372,33 @@ func useFromFile(fm *Frame, spec, path string, r diag.Ranger) (*Ns, error) {
 	if ns, ok := fm.Evaler.modules[path]; ok {
 		return ns, nil
 	}
-	code, err := readFileUTF8(path)
+	_, err := os.Stat(path + ".so")
 	if err != nil {
-		if os.IsNotExist(err) {
-			return nil, noSuchModule{spec}
+		code, err := readFileUTF8(path + ".elv")
+		if err != nil {
+			if os.IsNotExist(err) {
+				return nil, noSuchModule{spec}
+			}
+			return nil, err
 		}
+		src := parse.Source{Name: path + ".elv", Code: code, IsFile: true}
+		return evalModule(fm, path, src, r)
+	}
+
+	plug, err := pluginOpen(path + ".so")
+	if err != nil {
+		return nil, noSuchModule{spec}
+	}
+	sym, err := plug.Lookup("Ns")
+	if err != nil {
 		return nil, err
 	}
-	return evalModule(fm, path, parse.Source{Name: path, Code: code, IsFile: true}, r)
+	ns, ok := sym.(**Ns)
+	if !ok {
+		return nil, noSuchModule{spec}
+	}
+	fm.Evaler.modules[path] = *ns
+	return *ns, nil
 }
 
 // TODO: Make access to fm.Evaler.modules concurrency-safe.
@@ -404,7 +426,7 @@ func evalModule(fm *Frame, key string, src parse.Source, r diag.Ranger) (*Ns, er
 // false-ish values, the last value is output. If there are no arguments, it
 // outputs $true, as if there is a hidden $true before actual arguments.
 func compileAnd(cp *compiler, fn *parse.Form) effectOp {
-	return &andOrOp{cp.compoundOps(fn.Args), true, false}
+	return &andOrOp{fn.Range(), cp.compoundOps(fn.Args), true, false}
 }
 
 // compileOr compiles the "or" special form.
@@ -414,10 +436,11 @@ func compileAnd(cp *compiler, fn *parse.Form) effectOp {
 // true-ish values, the last value is output. If there are no arguments, it
 // outputs $false, as if there is a hidden $false before actual arguments.
 func compileOr(cp *compiler, fn *parse.Form) effectOp {
-	return &andOrOp{cp.compoundOps(fn.Args), false, true}
+	return &andOrOp{fn.Range(), cp.compoundOps(fn.Args), false, true}
 }
 
 type andOrOp struct {
+	diag.Ranging
 	argOps []valuesOp
 	init   bool
 	stopAt bool
@@ -425,6 +448,7 @@ type andOrOp struct {
 
 func (op *andOrOp) exec(fm *Frame) Exception {
 	var lastValue interface{} = vals.Bool(op.init)
+	out := fm.ValueOutput()
 	for _, argOp := range op.argOps {
 		values, exc := argOp.exec(fm)
 		if exc != nil {
@@ -432,26 +456,26 @@ func (op *andOrOp) exec(fm *Frame) Exception {
 		}
 		for _, value := range values {
 			if vals.Bool(value) == op.stopAt {
-				fm.OutputChan() <- value
-				return nil
+				return fm.errorp(op, out.Put(value))
 			}
 			lastValue = value
 		}
 	}
-	fm.OutputChan() <- lastValue
-	return nil
+	return fm.errorp(op, out.Put(lastValue))
 }
 
 func compileIf(cp *compiler, fn *parse.Form) effectOp {
 	args := cp.walkArgs(fn)
 	var condNodes []*parse.Compound
 	var bodyNodes []*parse.Primary
+	condLeader := "if"
 	for {
 		condNodes = append(condNodes, args.next())
-		bodyNodes = append(bodyNodes, args.nextMustLambda())
+		bodyNodes = append(bodyNodes, args.nextMustLambda(condLeader))
 		if !args.nextIs("elif") {
 			break
 		}
+		condLeader = "elif"
 	}
 	elseNode := args.nextMustLambdaIfAfter("else")
 	args.mustEnd()
@@ -497,7 +521,7 @@ func (op *ifOp) exec(fm *Frame) Exception {
 func compileWhile(cp *compiler, fn *parse.Form) effectOp {
 	args := cp.walkArgs(fn)
 	condNode := args.next()
-	bodyNode := args.nextMustLambda()
+	bodyNode := args.nextMustLambda("while body")
 	elseNode := args.nextMustLambdaIfAfter("else")
 	args.mustEnd()
 
@@ -553,7 +577,7 @@ func compileFor(cp *compiler, fn *parse.Form) effectOp {
 	args := cp.walkArgs(fn)
 	varNode := args.next()
 	iterNode := args.next()
-	bodyNode := args.nextMustLambda()
+	bodyNode := args.nextMustLambda("for body")
 	elseNode := args.nextMustLambdaIfAfter("else")
 	args.mustEnd()
 
@@ -580,7 +604,7 @@ type forOp struct {
 func (op *forOp) exec(fm *Frame) Exception {
 	variable, err := derefLValue(fm, op.lvalue)
 	if err != nil {
-		return fm.errorp(op, err)
+		return fm.errorp(op.lvalue, err)
 	}
 	iterable, err := evalForValue(fm, op.iterOp, "value being iterated")
 	if err != nil {
@@ -629,19 +653,19 @@ func (op *forOp) exec(fm *Frame) Exception {
 func compileTry(cp *compiler, fn *parse.Form) effectOp {
 	logger.Println("compiling try")
 	args := cp.walkArgs(fn)
-	bodyNode := args.nextMustLambda()
+	bodyNode := args.nextMustLambda("try body")
 	logger.Printf("body is %q", parse.SourceText(bodyNode))
 	var exceptVarNode *parse.Compound
 	var exceptNode *parse.Primary
 	if args.nextIs("except") {
 		logger.Println("except-ing")
+		// Parse an optional lvalue into exceptVarNode.
 		n := args.peek()
-		// Is this a variable?
-		if len(n.Indexings) == 1 && n.Indexings[0].Head.Type == parse.Bareword {
+		if _, ok := cmpd.StringLiteral(n); ok {
 			exceptVarNode = n
 			args.next()
 		}
-		exceptNode = args.nextMustLambda()
+		exceptNode = args.nextMustLambda("except body")
 	}
 	elseNode := args.nextMustLambdaIfAfter("else")
 	finallyNode := args.nextMustLambdaIfAfter("finally")
@@ -695,7 +719,7 @@ func (op *tryOp) exec(fm *Frame) Exception {
 			if exceptVar != nil {
 				err := exceptVar.Set(err.(Exception))
 				if err != nil {
-					return fm.errorp(op, err)
+					return fm.errorp(op.exceptVar, err)
 				}
 			}
 			err = except.Call(fm.fork("try except"), NoArgs, NoOpts)
