@@ -5,20 +5,20 @@ import (
 	"strings"
 	"testing"
 
-	. "github.com/elves/elvish/pkg/eval"
-	"github.com/elves/elvish/pkg/parse"
-	"github.com/elves/elvish/pkg/prog"
+	. "src.elv.sh/pkg/eval"
+	"src.elv.sh/pkg/parse"
+	"src.elv.sh/pkg/prog/progtest"
 )
 
 func TestDeprecatedBuiltin(t *testing.T) {
-	testCompileTimeDeprecation(t, "ord a", `the "ord" command is deprecated`, 15)
+	testCompileTimeDeprecation(t, "fopen a", `the "fopen" command is deprecated`, 16)
 	// Deprecations of other builtins are implemented in the same way, so we
 	// don't test them repeatedly
 }
 
 func testCompileTimeDeprecation(t *testing.T, code, wantWarning string, level int) {
-	restore := prog.SetDeprecationLevel(level)
-	defer restore()
+	t.Helper()
+	progtest.SetDeprecationLevel(t, level)
 
 	ev := NewEvaler()
 	errOutput := new(bytes.Buffer)
