@@ -1,11 +1,11 @@
 package store
 
 import (
-	"github.com/elves/elvish/pkg/eval"
-	"github.com/elves/elvish/pkg/store"
+	"src.elv.sh/pkg/eval"
+	"src.elv.sh/pkg/store/storedefs"
 )
 
-func Ns(s store.Store) *eval.Ns {
+func Ns(s storedefs.Store) *eval.Ns {
 	return eval.NsBuilder{}.AddGoFns("store:", map[string]interface{}{
 		"del-dir": s.DelDir,
 		"del-cmd": s.DelCmd,
